@@ -10,7 +10,7 @@ import json
 import sys
 
 import json_tools
-from .print_style import colorize
+from print_style import colorize
 
 
 def usage():
@@ -24,11 +24,7 @@ def usage():
         print("  ", colorize(cmd, bold=True), "\t", info)
 
 
-if len(sys.argv) < 3:
-    usage()
-    exit(-1)
-
-if sys.argv[1] == 'print':
+def pretty_print():
     try:
         with open(sys.argv[2]) as f:
             data = json.load(f)
@@ -37,7 +33,8 @@ if sys.argv[1] == 'print':
         exit(-1)
     json_tools.print_json(data, '--pretty' in sys.argv)
 
-elif sys.argv[1] == 'diff':
+
+def diff():
     try:
         with open(sys.argv[2]) as f:
             local = json.load(f)
@@ -61,7 +58,8 @@ elif sys.argv[1] == 'diff':
     res = json_tools.diff(local, other)
     json_tools.print_json(res, '--pretty' in sys.argv)
 
-elif sys.argv[1] == 'patch':
+
+def patch():
     try:
         with open(sys.argv[2]) as f:
             data = json.load(f)
@@ -84,3 +82,25 @@ elif sys.argv[1] == 'patch':
 
     res = json_tools.patch(data, patch)
     json_tools.print_json(res, '--pretty' in sys.argv)
+
+
+COMMANDS = {
+    'print': pretty_print,
+    'diff': diff,
+    'patch': patch
+}
+
+
+def main():
+    if len(sys.argv) < 3:
+        usage()
+        exit(-1)
+    else:
+        try:
+            COMMANDS[sys.argv[1]]()
+        except KeyError:
+            print('Bad command:', sys.argv[1], file=sys.stderr)
+
+
+if __name__ == '__main__':
+    main()
